@@ -1,3 +1,5 @@
+import ConfigParser
+import os
 from requests.auth import HTTPBasicAuth
 
 import tutum
@@ -43,4 +45,17 @@ def logout():
     Sets the tutum user and apikey to None
     """
     tutum.user = None
-    tutum.apikey = None
\ No newline at end of file
+    tutum.apikey = None
+
+
+def load_from_file(file="~/.tutum"):
+    """
+    Attempts to read tutum's credentials from a config file and return a tuple of (user,apikey)
+    """
+    try:
+        cfgfile = os.path.expanduser(file)
+        cp = ConfigParser.ConfigParser()
+        cp.read(cfgfile)
+        return (cp.get("auth", "user"), cp.get("auth", "apikey"))
+    except ConfigParser.Error:
+        return (None, None)
\ No newline at end of file
