@@ -1,5 +1,4 @@
 import json as json_parser
-from urlparse import urljoin
 
 from http import send_request
 from tutum.api.exceptions import TutumApiError
@@ -69,7 +68,7 @@ class RESTModel(object):
         """
         containers = []
         endpoint = getattr(cls, 'endpoint', None)
-        assert endpoint, "Endpoint not specified for %s" % self.__class__.__name__
+        assert endpoint, "Endpoint not specified for %s" % cls.__name__
         json = send_request('GET', endpoint)
         if json:
             json_objects = json.get('objects', [])
@@ -86,7 +85,7 @@ class RESTModel(object):
         """
         instance = None
         endpoint = getattr(cls, 'endpoint', None)
-        assert endpoint, "Endpoint not specified for %s" % self.__class__.__name__
+        assert endpoint, "Endpoint not specified for %s" % cls.__name__
         detail_uri = "/".join([endpoint, pk])
         json = send_request('GET', detail_uri)
         if json:
@@ -194,4 +193,13 @@ class RESTModel(object):
         """
         Returns a new instance of the model (without saving it)
         """
-        return cls(**kwargs)
\ No newline at end of file
+        return cls(**kwargs)
+
+    def get_all_attributes(self):
+        """
+        Returns a dict with all object attributes
+        """
+        attributes = {}
+        for attr in [attr for attr in vars(self) if not attr.startswith('_')]:
+            attributes[attr] = getattr(self, attr, None)
+        return attributes
\ No newline at end of file
