@@ -1,10 +1,9 @@
-import logging
 from urlparse import urljoin
 
 from requests import Request, Session
 
 import tutum
-from tutum.api.exceptions import TutumApiError
+from tutum.api.exceptions import TutumApiError, TutumAuthError
 
 
 def send_request(method, path, **kwargs):
@@ -12,7 +11,7 @@ def send_request(method, path, **kwargs):
     url  = urljoin(tutum.base_url, path.strip("/"))
     if not url.endswith("/"):
         url = "%s/" % url
-    logging.info("%s %s %s" % (method, url, kwargs))
+    tutum.logger.info("%s %s %s" % (method, url, kwargs))
     # construct headers
     headers = {}
     headers['Content-Type']  = 'application/json'
@@ -25,7 +24,7 @@ def send_request(method, path, **kwargs):
     # make the request
     response = s.send(req.prepare())
     status_code = getattr(response, 'status_code', None)
-    logging.info("Status: %s", str(status_code))
+    tutum.logger.info("Status: %s", str(status_code))
     # handle the response
     if not status_code:
         # Most likely network trouble
@@ -35,10 +34,13 @@ def send_request(method, path, **kwargs):
         try:
             json = response.json()
         except Exception as e:
-            logging.error("Response: %s", response.text)
+            tutum.logger.error("Response: %s", response.text)
             raise TutumApiError("JSON Parse Error (%s %s)" % (method, url))
     else:
-         # Server returned an error.
-        logging.error("Response: %s", response.text)
-        raise TutumApiError("Status %s (%s %s)" % (str(status_code), method, url))
+        # Server returned an error.
+        if status_code == 401:
+            raise TutumAuthError("Not authorized")
+        else:
+            tutum.logger.error("Response: %s", response.text)
+            raise TutumApiError("Status %s (%s %s)" % (str(status_code), method, url))
     return json
\ No newline at end of file
